# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class CustomAgentsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_custom_agent(self, **kwargs):
        """
        Archive a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_custom_agent(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_custom_agent_with_http_info(**kwargs)
        else:
            (data) = self.archive_custom_agent_with_http_info(**kwargs)
            return data

    def archive_custom_agent_with_http_info(self, **kwargs):
        """
        Archive a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_custom_agent_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_custom_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_custom_agent`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ArchiveOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_custom_agent(self, **kwargs):
        """
        Create a new custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_agent(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentInputV1 body: (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_custom_agent_with_http_info(**kwargs)
        else:
            (data) = self.create_custom_agent_with_http_info(**kwargs)
            return data

    def create_custom_agent_with_http_info(self, **kwargs):
        """
        Create a new custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_agent_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentInputV1 body: (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_custom_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_custom_agent`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_custom_agent_draft(self, **kwargs):
        """
        Create the current user's custom agent draft working copy. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_agent_draft(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentDraftCreateInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_custom_agent_draft_with_http_info(**kwargs)
        else:
            (data) = self.create_custom_agent_draft_with_http_info(**kwargs)
            return data

    def create_custom_agent_draft_with_http_info(self, **kwargs):
        """
        Create the current user's custom agent draft working copy. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_agent_draft_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentDraftCreateInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_custom_agent_draft" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_custom_agent_draft`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_custom_agent_draft`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/draft', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_custom_agent_version(self, **kwargs):
        """
        Create a new version from the caller's draft. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_agent_version(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentVersionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentVersionOutputV1]
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_custom_agent_version_with_http_info(**kwargs)
        else:
            (data) = self.create_custom_agent_version_with_http_info(**kwargs)
            return data

    def create_custom_agent_version_with_http_info(self, **kwargs):
        """
        Create a new version from the caller's draft. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_custom_agent_version_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentVersionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentVersionOutputV1]
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_custom_agent_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `create_custom_agent_version`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/versions', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'list[CustomAgentVersionOutputV1]'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def discard_custom_agent_draft(self, **kwargs):
        """
        Discard the caller's draft working copy for a versioned custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.discard_custom_agent_draft(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.discard_custom_agent_draft_with_http_info(**kwargs)
        else:
            (data) = self.discard_custom_agent_draft_with_http_info(**kwargs)
            return data

    def discard_custom_agent_draft_with_http_info(self, **kwargs):
        """
        Discard the caller's draft working copy for a versioned custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.discard_custom_agent_draft_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method discard_custom_agent_draft" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `discard_custom_agent_draft`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/draft', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', None),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def duplicate_custom_agent(self, **kwargs):
        """
        Duplicate a custom agent from its production version. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.duplicate_custom_agent(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.duplicate_custom_agent_with_http_info(**kwargs)
        else:
            (data) = self.duplicate_custom_agent_with_http_info(**kwargs)
            return data

    def duplicate_custom_agent_with_http_info(self, **kwargs):
        """
        Duplicate a custom agent from its production version. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.duplicate_custom_agent_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method duplicate_custom_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `duplicate_custom_agent`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/duplicate', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_agent(self, **kwargs):
        """
        Get a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_agent_with_http_info(**kwargs)
        else:
            (data) = self.get_custom_agent_with_http_info(**kwargs)
            return data

    def get_custom_agent_with_http_info(self, **kwargs):
        """
        Get a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_custom_agent`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_agent_draft_working_copies(self, **kwargs):
        """
        Get a list of active drafts for a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_draft_working_copies(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentDraftOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentDraftOutputV1]
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_agent_draft_working_copies_with_http_info(**kwargs)
        else:
            (data) = self.get_custom_agent_draft_working_copies_with_http_info(**kwargs)
            return data

    def get_custom_agent_draft_working_copies_with_http_info(self, **kwargs):
        """
        Get a list of active drafts for a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_draft_working_copies_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentDraftOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentDraftOutputV1]
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_agent_draft_working_copies" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_custom_agent_draft_working_copies`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/drafts', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'list[CustomAgentDraftOutputV1]'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_agent_version_graph(self, **kwargs):
        """
        Get a workflow graph for a specific version. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_version_graph(id=id_value, version_id=version_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :param str version_id: The version ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_agent_version_graph_with_http_info(**kwargs)
        else:
            (data) = self.get_custom_agent_version_graph_with_http_info(**kwargs)
            return data

    def get_custom_agent_version_graph_with_http_info(self, **kwargs):
        """
        Get a workflow graph for a specific version. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_version_graph_with_http_info(id=id_value, version_id=version_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :param str version_id: The version ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['id', 'version_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_agent_version_graph" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_custom_agent_version_graph`")
        # verify the required parameter 'version_id' is set
        if ('version_id' not in params) or (params['version_id'] is None):
            raise ValueError("Missing the required parameter `version_id` when calling `get_custom_agent_version_graph`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/versions/{versionId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_agent_versions(self, **kwargs):
        """
        Get versions for a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_versions(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentVersionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentVersionOutputV1]
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_agent_versions_with_http_info(**kwargs)
        else:
            (data) = self.get_custom_agent_versions_with_http_info(**kwargs)
            return data

    def get_custom_agent_versions_with_http_info(self, **kwargs):
        """
        Get versions for a custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agent_versions_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentVersionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentVersionOutputV1]
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_agent_versions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_custom_agent_versions`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/versions', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'list[CustomAgentVersionOutputV1]'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_custom_agents(self, **kwargs):
        """
        Get a list of custom agents. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agents(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool versioned: Filter by versioned state
        :param str production: Production filter: any, set, or unset
        :param str ownership: Ownership filter: all or mine
        :param int offset: The pagination offset, the number of matching items to skip
        :param int limit: The pagination limit, the maximum number of items to return
        :return: list[CustomAgentSummaryOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentSummaryOutputV1]
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_custom_agents_with_http_info(**kwargs)
        else:
            (data) = self.get_custom_agents_with_http_info(**kwargs)
            return data

    def get_custom_agents_with_http_info(self, **kwargs):
        """
        Get a list of custom agents. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_custom_agents_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool versioned: Filter by versioned state
        :param str production: Production filter: any, set, or unset
        :param str ownership: Ownership filter: all or mine
        :param int offset: The pagination offset, the number of matching items to skip
        :param int limit: The pagination limit, the maximum number of items to return
        :return: list[CustomAgentSummaryOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentSummaryOutputV1]
        """

        all_params = ['versioned', 'production', 'ownership', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_agents" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'versioned' in params:
            query_params.append(('versioned', params['versioned']))
        if 'production' in params:
            query_params.append(('production', params['production']))
        if 'ownership' in params:
            query_params.append(('ownership', params['ownership']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'list[CustomAgentSummaryOutputV1]'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def revert_custom_agent_to_version(self, **kwargs):
        """
        Revert the caller's draft working copy to a specific version. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.revert_custom_agent_to_version(id=id_value, version_id=version_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :param str version_id: The version ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.revert_custom_agent_to_version_with_http_info(**kwargs)
        else:
            (data) = self.revert_custom_agent_to_version_with_http_info(**kwargs)
            return data

    def revert_custom_agent_to_version_with_http_info(self, **kwargs):
        """
        Revert the caller's draft working copy to a specific version. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.revert_custom_agent_to_version_with_http_info(id=id_value, version_id=version_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The custom agent ID (required)
        :param str version_id: The version ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['id', 'version_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revert_custom_agent_to_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `revert_custom_agent_to_version`")
        # verify the required parameter 'version_id' is set
        if ('version_id' not in params) or (params['version_id'] is None):
            raise ValueError("Missing the required parameter `version_id` when calling `revert_custom_agent_to_version`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/revert/{versionId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def set_custom_agent_production(self, **kwargs):
        """
        Set or unset the production version for the custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.set_custom_agent_production(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentProductionInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentVersionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentVersionOutputV1]
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.set_custom_agent_production_with_http_info(**kwargs)
        else:
            (data) = self.set_custom_agent_production_with_http_info(**kwargs)
            return data

    def set_custom_agent_production_with_http_info(self, **kwargs):
        """
        Set or unset the production version for the custom agent. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.set_custom_agent_production_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentProductionInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: list[CustomAgentVersionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[CustomAgentVersionOutputV1]
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_custom_agent_production" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `set_custom_agent_production`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `set_custom_agent_production`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/production', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'list[CustomAgentVersionOutputV1]'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_custom_agent(self, **kwargs):
        """
        Update custom agent metadata without modifying draft workflow state. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_custom_agent(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentMetadataUpdateInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_custom_agent_with_http_info(**kwargs)
        else:
            (data) = self.update_custom_agent_with_http_info(**kwargs)
            return data

    def update_custom_agent_with_http_info(self, **kwargs):
        """
        Update custom agent metadata without modifying draft workflow state. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_custom_agent_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentMetadataUpdateInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_custom_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_custom_agent`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_custom_agent`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_custom_agent_draft(self, **kwargs):
        """
        Update the current user's custom agent draft working copy. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_custom_agent_draft(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentDraftUpdateInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_custom_agent_draft_with_http_info(**kwargs)
        else:
            (data) = self.update_custom_agent_draft_with_http_info(**kwargs)
            return data

    def update_custom_agent_draft_with_http_info(self, **kwargs):
        """
        Update the current user's custom agent draft working copy. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_custom_agent_draft_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CustomAgentDraftUpdateInputV1 body: (required)
        :param str id: The custom agent ID (required)
        :return: CustomAgentOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CustomAgentOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_custom_agent_draft" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_custom_agent_draft`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_custom_agent_draft`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/custom-agents/{id}/draft', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CustomAgentOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemParameterOfOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestors: Optional[List[ItemPreviewV1]]
    _has_active_children: Optional[bool]
    _has_children: Optional[bool]
    _id: str
    _is_archived: Optional[bool]
    _is_generated: Optional[bool]
    _is_redacted: Optional[bool]
    _name: str
    _parameter_of: Optional[List[ItemPreviewWithAssetsV1]]
    _translation_key: Optional[str]
    _type: str


    def __init__(
        self,
        ancestors: Optional[List[ItemPreviewV1]] = None,
        has_active_children: Optional[bool] = False,
        has_children: Optional[bool] = False,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_generated: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        name: Optional[str] = None,
        parameter_of: Optional[List[ItemPreviewWithAssetsV1]] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def ancestors(self) -> Optional[List[ItemPreviewV1]]: ...

    @ancestors.setter
    def ancestors(self, ancestors: Optional[List[ItemPreviewV1]]) -> None: ...

    @property
    def has_active_children(self) -> Optional[bool]: ...

    @has_active_children.setter
    def has_active_children(self, has_active_children: Optional[bool]) -> None: ...

    @property
    def has_children(self) -> Optional[bool]: ...

    @has_children.setter
    def has_children(self, has_children: Optional[bool]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_generated(self) -> Optional[bool]: ...

    @is_generated.setter
    def is_generated(self, is_generated: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def parameter_of(self) -> Optional[List[ItemPreviewWithAssetsV1]]: ...

    @parameter_of.setter
    def parameter_of(self, parameter_of: Optional[List[ItemPreviewWithAssetsV1]]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ViewColumnInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_definition': 'str',
        'group_order': 'int',
        'sort_ascending': 'bool',
        'sort_index': 'int',
        'view_column_filters': 'list[ViewColumnFilterInputV1]'
    }

    attribute_map = {
        'column_definition': 'columnDefinition',
        'group_order': 'groupOrder',
        'sort_ascending': 'sortAscending',
        'sort_index': 'sortIndex',
        'view_column_filters': 'viewColumnFilters'
    }

    def __init__(self, column_definition=None, group_order=None, sort_ascending=None, sort_index=None, view_column_filters=None):
        """
        ViewColumnInputV1 - a model defined in Swagger
        """

        self._column_definition = None
        self._group_order = None
        self._sort_ascending = None
        self._sort_index = None
        self._view_column_filters = None

        if column_definition is not None:
          self.column_definition = column_definition
        if group_order is not None:
          self.group_order = group_order
        if sort_ascending is not None:
          self.sort_ascending = sort_ascending
        if sort_index is not None:
          self.sort_index = sort_index
        if view_column_filters is not None:
          self.view_column_filters = view_column_filters

    @property
    def column_definition(self):
        """
        Gets the column_definition of this ViewColumnInputV1.
        ID of the Column Definition in the Item Table that generates the View Column for the Item Hierarchy.

        :return: The column_definition of this ViewColumnInputV1.
        :rtype: str
        """
        return self._column_definition

    @column_definition.setter
    def column_definition(self, column_definition):
        """
        Sets the column_definition of this ViewColumnInputV1.
        ID of the Column Definition in the Item Table that generates the View Column for the Item Hierarchy.

        :param column_definition: The column_definition of this ViewColumnInputV1.
        :type: str
        """

        self._column_definition = column_definition

    @property
    def group_order(self):
        """
        Gets the group_order of this ViewColumnInputV1.
        The grouping order for this column. If not provided, the column is not grouped to create the Hierarchy. Lower grouping order values will be grouped first indicating they are at a higher level in the hierarchy. 

        :return: The group_order of this ViewColumnInputV1.
        :rtype: int
        """
        return self._group_order

    @group_order.setter
    def group_order(self, group_order):
        """
        Sets the group_order of this ViewColumnInputV1.
        The grouping order for this column. If not provided, the column is not grouped to create the Hierarchy. Lower grouping order values will be grouped first indicating they are at a higher level in the hierarchy. 

        :param group_order: The group_order of this ViewColumnInputV1.
        :type: int
        """

        self._group_order = group_order

    @property
    def sort_ascending(self):
        """
        Gets the sort_ascending of this ViewColumnInputV1.
        Whether to sort ascending if sortIndex is provided, defaults to false

        :return: The sort_ascending of this ViewColumnInputV1.
        :rtype: bool
        """
        return self._sort_ascending

    @sort_ascending.setter
    def sort_ascending(self, sort_ascending):
        """
        Sets the sort_ascending of this ViewColumnInputV1.
        Whether to sort ascending if sortIndex is provided, defaults to false

        :param sort_ascending: The sort_ascending of this ViewColumnInputV1.
        :type: bool
        """

        self._sort_ascending = sort_ascending

    @property
    def sort_index(self):
        """
        Gets the sort_index of this ViewColumnInputV1.
        The sort index for this column. If not provided, the column is not sorted.

        :return: The sort_index of this ViewColumnInputV1.
        :rtype: int
        """
        return self._sort_index

    @sort_index.setter
    def sort_index(self, sort_index):
        """
        Sets the sort_index of this ViewColumnInputV1.
        The sort index for this column. If not provided, the column is not sorted.

        :param sort_index: The sort_index of this ViewColumnInputV1.
        :type: int
        """

        self._sort_index = sort_index

    @property
    def view_column_filters(self):
        """
        Gets the view_column_filters of this ViewColumnInputV1.
        The filters to be applied to the view column. If not provided, no filters are applied.

        :return: The view_column_filters of this ViewColumnInputV1.
        :rtype: list[ViewColumnFilterInputV1]
        """
        return self._view_column_filters

    @view_column_filters.setter
    def view_column_filters(self, view_column_filters):
        """
        Sets the view_column_filters of this ViewColumnInputV1.
        The filters to be applied to the view column. If not provided, no filters are applied.

        :param view_column_filters: The view_column_filters of this ViewColumnInputV1.
        :type: list[ViewColumnFilterInputV1]
        """

        self._view_column_filters = view_column_filters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ViewColumnInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentMetaOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'draft': 'CustomAgentDraftInfoOutputV1',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'draft': 'draft',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, draft=None, updated_at=None):
        """
        CustomAgentMetaOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._draft = None
        self._updated_at = None

        if created_at is not None:
          self.created_at = created_at
        if draft is not None:
          self.draft = draft
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def created_at(self):
        """
        Gets the created_at of this CustomAgentMetaOutputV1.
        The time the custom agent was created

        :return: The created_at of this CustomAgentMetaOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this CustomAgentMetaOutputV1.
        The time the custom agent was created

        :param created_at: The created_at of this CustomAgentMetaOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def draft(self):
        """
        Gets the draft of this CustomAgentMetaOutputV1.

        :return: The draft of this CustomAgentMetaOutputV1.
        :rtype: CustomAgentDraftInfoOutputV1
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """
        Sets the draft of this CustomAgentMetaOutputV1.

        :param draft: The draft of this CustomAgentMetaOutputV1.
        :type: CustomAgentDraftInfoOutputV1
        """
        if draft is None:
            raise ValueError("Invalid value for `draft`, must not be `None`")

        self._draft = draft

    @property
    def updated_at(self):
        """
        Gets the updated_at of this CustomAgentMetaOutputV1.
        The time the custom agent (or visible draft) was last updated

        :return: The updated_at of this CustomAgentMetaOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this CustomAgentMetaOutputV1.
        The time the custom agent (or visible draft) was last updated

        :param updated_at: The updated_at of this CustomAgentMetaOutputV1.
        :type: str
        """
        if updated_at is None:
            raise ValueError("Invalid value for `updated_at`, must not be `None`")

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentMetaOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RadialRehydrationInstructionsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'selected_series_names': 'list[str]',
        'series_identifier': 'str',
        'time_key': 'str'
    }

    attribute_map = {
        'selected_series_names': 'selectedSeriesNames',
        'series_identifier': 'seriesIdentifier',
        'time_key': 'timeKey'
    }

    def __init__(self, selected_series_names=None, series_identifier=None, time_key=None):
        """
        RadialRehydrationInstructionsOutputV1 - a model defined in Swagger
        """

        self._selected_series_names = None
        self._series_identifier = None
        self._time_key = None

        if selected_series_names is not None:
          self.selected_series_names = selected_series_names
        if series_identifier is not None:
          self.series_identifier = series_identifier
        if time_key is not None:
          self.time_key = time_key

    @property
    def selected_series_names(self):
        """
        Gets the selected_series_names of this RadialRehydrationInstructionsOutputV1.
        Specific series names that are hydrated for the chart

        :return: The selected_series_names of this RadialRehydrationInstructionsOutputV1.
        :rtype: list[str]
        """
        return self._selected_series_names

    @selected_series_names.setter
    def selected_series_names(self, selected_series_names):
        """
        Sets the selected_series_names of this RadialRehydrationInstructionsOutputV1.
        Specific series names that are hydrated for the chart

        :param selected_series_names: The selected_series_names of this RadialRehydrationInstructionsOutputV1.
        :type: list[str]
        """
        if selected_series_names is None:
            raise ValueError("Invalid value for `selected_series_names`, must not be `None`")

        self._selected_series_names = selected_series_names

    @property
    def series_identifier(self):
        """
        Gets the series_identifier of this RadialRehydrationInstructionsOutputV1.
        Identifier that maps radial data to chart options

        :return: The series_identifier of this RadialRehydrationInstructionsOutputV1.
        :rtype: str
        """
        return self._series_identifier

    @series_identifier.setter
    def series_identifier(self, series_identifier):
        """
        Sets the series_identifier of this RadialRehydrationInstructionsOutputV1.
        Identifier that maps radial data to chart options

        :param series_identifier: The series_identifier of this RadialRehydrationInstructionsOutputV1.
        :type: str
        """
        if series_identifier is None:
            raise ValueError("Invalid value for `series_identifier`, must not be `None`")

        self._series_identifier = series_identifier

    @property
    def time_key(self):
        """
        Gets the time_key of this RadialRehydrationInstructionsOutputV1.
        The data column used as the time key for radial chart rehydration

        :return: The time_key of this RadialRehydrationInstructionsOutputV1.
        :rtype: str
        """
        return self._time_key

    @time_key.setter
    def time_key(self, time_key):
        """
        Sets the time_key of this RadialRehydrationInstructionsOutputV1.
        The data column used as the time key for radial chart rehydration

        :param time_key: The time_key of this RadialRehydrationInstructionsOutputV1.
        :type: str
        """
        if time_key is None:
            raise ValueError("Invalid value for `time_key`, must not be `None`")

        self._time_key = time_key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RadialRehydrationInstructionsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import annotations

from typing import List

# `seeq` is a namespace package (PEP 420). This stub file exists to mark the
# distribution as typed (PEP 561) and to make type checkers treat `seeq` as a package.
__path__: List[str]




# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConnectionStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_name: str
    _agent_version_required: Optional[str]
    _connection_id: str
    _connection_message: Optional[str]
    _connector_developer_name: Optional[str]
    _connector_developer_support_url: Optional[str]
    _connector_name: Optional[str]
    _created_at: Optional[str]
    _datasource_managed: Optional[bool]
    _disabled_at: Optional[str]
    _disabled_by: Optional[str]
    _has_error: Optional[bool]
    _last_successful_connected_at: Optional[str]
    _name: str
    _status: Optional[str]
    _sync_status: Optional[str]
    _version: Optional[str]


    def __init__(
        self,
        agent_name: Optional[str] = None,
        agent_version_required: Optional[str] = None,
        connection_id: Optional[str] = None,
        connection_message: Optional[str] = None,
        connector_developer_name: Optional[str] = None,
        connector_developer_support_url: Optional[str] = None,
        connector_name: Optional[str] = None,
        created_at: Optional[str] = None,
        datasource_managed: Optional[bool] = False,
        disabled_at: Optional[str] = None,
        disabled_by: Optional[str] = None,
        has_error: Optional[bool] = False,
        last_successful_connected_at: Optional[str] = None,
        name: Optional[str] = None,
        status: Optional[str] = None,
        sync_status: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_name(self) -> str: ...

    @agent_name.setter
    def agent_name(self, agent_name: str) -> None: ...

    @property
    def agent_version_required(self) -> Optional[str]: ...

    @agent_version_required.setter
    def agent_version_required(self, agent_version_required: Optional[str]) -> None: ...

    @property
    def connection_id(self) -> str: ...

    @connection_id.setter
    def connection_id(self, connection_id: str) -> None: ...

    @property
    def connection_message(self) -> Optional[str]: ...

    @connection_message.setter
    def connection_message(self, connection_message: Optional[str]) -> None: ...

    @property
    def connector_developer_name(self) -> Optional[str]: ...

    @connector_developer_name.setter
    def connector_developer_name(self, connector_developer_name: Optional[str]) -> None: ...

    @property
    def connector_developer_support_url(self) -> Optional[str]: ...

    @connector_developer_support_url.setter
    def connector_developer_support_url(self, connector_developer_support_url: Optional[str]) -> None: ...

    @property
    def connector_name(self) -> Optional[str]: ...

    @connector_name.setter
    def connector_name(self, connector_name: Optional[str]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def datasource_managed(self) -> Optional[bool]: ...

    @datasource_managed.setter
    def datasource_managed(self, datasource_managed: Optional[bool]) -> None: ...

    @property
    def disabled_at(self) -> Optional[str]: ...

    @disabled_at.setter
    def disabled_at(self, disabled_at: Optional[str]) -> None: ...

    @property
    def disabled_by(self) -> Optional[str]: ...

    @disabled_by.setter
    def disabled_by(self, disabled_by: Optional[str]) -> None: ...

    @property
    def has_error(self) -> Optional[bool]: ...

    @has_error.setter
    def has_error(self, has_error: Optional[bool]) -> None: ...

    @property
    def last_successful_connected_at(self) -> Optional[str]: ...

    @last_successful_connected_at.setter
    def last_successful_connected_at(self, last_successful_connected_at: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def sync_status(self) -> Optional[str]: ...

    @sync_status.setter
    def sync_status(self, sync_status: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LastRunStateOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _condition_guid: str
    _cursor_key: Optional[int]
    _earliest_uncertain_end_time_capsule_start: Optional[int]
    _error_count: Optional[int]
    _id_property: Optional[str]
    _last_error: Optional[str]
    _last_error_time_created: Optional[int]
    _uncertain_capsule_ids: Optional[List[str]]


    def __init__(
        self,
        condition_guid: Optional[str] = None,
        cursor_key: Optional[int] = None,
        earliest_uncertain_end_time_capsule_start: Optional[int] = None,
        error_count: Optional[int] = None,
        id_property: Optional[str] = None,
        last_error: Optional[str] = None,
        last_error_time_created: Optional[int] = None,
        uncertain_capsule_ids: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def condition_guid(self) -> str: ...

    @condition_guid.setter
    def condition_guid(self, condition_guid: str) -> None: ...

    @property
    def cursor_key(self) -> Optional[int]: ...

    @cursor_key.setter
    def cursor_key(self, cursor_key: Optional[int]) -> None: ...

    @property
    def earliest_uncertain_end_time_capsule_start(self) -> Optional[int]: ...

    @earliest_uncertain_end_time_capsule_start.setter
    def earliest_uncertain_end_time_capsule_start(self, earliest_uncertain_end_time_capsule_start: Optional[int]) -> None: ...

    @property
    def error_count(self) -> Optional[int]: ...

    @error_count.setter
    def error_count(self, error_count: Optional[int]) -> None: ...

    @property
    def id_property(self) -> Optional[str]: ...

    @id_property.setter
    def id_property(self, id_property: Optional[str]) -> None: ...

    @property
    def last_error(self) -> Optional[str]: ...

    @last_error.setter
    def last_error(self, last_error: Optional[str]) -> None: ...

    @property
    def last_error_time_created(self) -> Optional[int]: ...

    @last_error_time_created.setter
    def last_error_time_created(self, last_error_time_created: Optional[int]) -> None: ...

    @property
    def uncertain_capsule_ids(self) -> Optional[List[str]]: ...

    @uncertain_capsule_ids.setter
    def uncertain_capsule_ids(self, uncertain_capsule_ids: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class SubscriptionsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def get_channels(
        self,
        **kwargs: Any,
    ) -> GetChannelsOutputV1: ...

    def get_channels_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def subscribe(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def subscribe_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unsubscribe(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def unsubscribe_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_subscription(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def update_subscription_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class PutScalarInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_properties: Optional[List[ScalarPropertyV1]]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _formula: str
    _host_id: Optional[str]
    _name: str
    _number_format: Optional[str]
    _parameters: Optional[List[str]]
    _previous_data_id: Optional[str]
    _properties: Optional[List[ScalarPropertyV1]]
    _properties_to_remove: Optional[List[str]]
    _scoped_to: Optional[str]
    _security_string: Optional[str]
    _source_security_string: Optional[str]
    _sync_token: Optional[str]
    _unit_of_measure: Optional[str]


    def __init__(
        self,
        additional_properties: Optional[List[ScalarPropertyV1]] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        formula: Optional[str] = None,
        host_id: Optional[str] = None,
        name: Optional[str] = None,
        number_format: Optional[str] = None,
        parameters: Optional[List[str]] = None,
        previous_data_id: Optional[str] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        properties_to_remove: Optional[List[str]] = None,
        scoped_to: Optional[str] = None,
        security_string: Optional[str] = None,
        source_security_string: Optional[str] = None,
        sync_token: Optional[str] = None,
        unit_of_measure: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @additional_properties.setter
    def additional_properties(self, additional_properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def formula(self) -> str: ...

    @formula.setter
    def formula(self, formula: str) -> None: ...

    @property
    def host_id(self) -> Optional[str]: ...

    @host_id.setter
    def host_id(self, host_id: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def number_format(self) -> Optional[str]: ...

    @number_format.setter
    def number_format(self, number_format: Optional[str]) -> None: ...

    @property
    def parameters(self) -> Optional[List[str]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[str]]) -> None: ...

    @property
    def previous_data_id(self) -> Optional[str]: ...

    @previous_data_id.setter
    def previous_data_id(self, previous_data_id: Optional[str]) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def properties_to_remove(self) -> Optional[List[str]]: ...

    @properties_to_remove.setter
    def properties_to_remove(self, properties_to_remove: Optional[List[str]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def security_string(self) -> Optional[str]: ...

    @security_string.setter
    def security_string(self, security_string: Optional[str]) -> None: ...

    @property
    def source_security_string(self) -> Optional[str]: ...

    @source_security_string.setter
    def source_security_string(self, source_security_string: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    @property
    def unit_of_measure(self) -> Optional[str]: ...

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CacheBlock(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'authoritative_region': 'AuthoritativeRegionOutputV1',
        'blob_id': 'int',
        'capsules': 'list[CapsuleV1]',
        'creation_time': 'str',
        'cursor': 'str',
        'last_access_time': 'str',
        'length_in_bytes': 'int',
        'length_in_datums': 'int',
        'record_id': 'int',
        'samples': 'list[SampleOutputV1]',
        'series_id': 'str',
        'ttl': 'int'
    }

    attribute_map = {
        'authoritative_region': 'authoritativeRegion',
        'blob_id': 'blobId',
        'capsules': 'capsules',
        'creation_time': 'creationTime',
        'cursor': 'cursor',
        'last_access_time': 'lastAccessTime',
        'length_in_bytes': 'lengthInBytes',
        'length_in_datums': 'lengthInDatums',
        'record_id': 'recordId',
        'samples': 'samples',
        'series_id': 'seriesId',
        'ttl': 'ttl'
    }

    def __init__(self, authoritative_region=None, blob_id=None, capsules=None, creation_time=None, cursor=None, last_access_time=None, length_in_bytes=None, length_in_datums=None, record_id=None, samples=None, series_id=None, ttl=None):
        """
        CacheBlock - a model defined in Swagger
        """

        self._authoritative_region = None
        self._blob_id = None
        self._capsules = None
        self._creation_time = None
        self._cursor = None
        self._last_access_time = None
        self._length_in_bytes = None
        self._length_in_datums = None
        self._record_id = None
        self._samples = None
        self._series_id = None
        self._ttl = None

        if authoritative_region is not None:
          self.authoritative_region = authoritative_region
        if blob_id is not None:
          self.blob_id = blob_id
        if capsules is not None:
          self.capsules = capsules
        if creation_time is not None:
          self.creation_time = creation_time
        if cursor is not None:
          self.cursor = cursor
        if last_access_time is not None:
          self.last_access_time = last_access_time
        if length_in_bytes is not None:
          self.length_in_bytes = length_in_bytes
        if length_in_datums is not None:
          self.length_in_datums = length_in_datums
        if record_id is not None:
          self.record_id = record_id
        if samples is not None:
          self.samples = samples
        if series_id is not None:
          self.series_id = series_id
        if ttl is not None:
          self.ttl = ttl

    @property
    def authoritative_region(self):
        """
        Gets the authoritative_region of this CacheBlock.

        :return: The authoritative_region of this CacheBlock.
        :rtype: AuthoritativeRegionOutputV1
        """
        return self._authoritative_region

    @authoritative_region.setter
    def authoritative_region(self, authoritative_region):
        """
        Sets the authoritative_region of this CacheBlock.

        :param authoritative_region: The authoritative_region of this CacheBlock.
        :type: AuthoritativeRegionOutputV1
        """

        self._authoritative_region = authoritative_region

    @property
    def blob_id(self):
        """
        Gets the blob_id of this CacheBlock.

        :return: The blob_id of this CacheBlock.
        :rtype: int
        """
        return self._blob_id

    @blob_id.setter
    def blob_id(self, blob_id):
        """
        Sets the blob_id of this CacheBlock.

        :param blob_id: The blob_id of this CacheBlock.
        :type: int
        """

        self._blob_id = blob_id

    @property
    def capsules(self):
        """
        Gets the capsules of this CacheBlock.

        :return: The capsules of this CacheBlock.
        :rtype: list[CapsuleV1]
        """
        return self._capsules

    @capsules.setter
    def capsules(self, capsules):
        """
        Sets the capsules of this CacheBlock.

        :param capsules: The capsules of this CacheBlock.
        :type: list[CapsuleV1]
        """

        self._capsules = capsules

    @property
    def creation_time(self):
        """
        Gets the creation_time of this CacheBlock.

        :return: The creation_time of this CacheBlock.
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """
        Sets the creation_time of this CacheBlock.

        :param creation_time: The creation_time of this CacheBlock.
        :type: str
        """

        self._creation_time = creation_time

    @property
    def cursor(self):
        """
        Gets the cursor of this CacheBlock.

        :return: The cursor of this CacheBlock.
        :rtype: str
        """
        return self._cursor

    @cursor.setter
    def cursor(self, cursor):
        """
        Sets the cursor of this CacheBlock.

        :param cursor: The cursor of this CacheBlock.
        :type: str
        """

        self._cursor = cursor

    @property
    def last_access_time(self):
        """
        Gets the last_access_time of this CacheBlock.

        :return: The last_access_time of this CacheBlock.
        :rtype: str
        """
        return self._last_access_time

    @last_access_time.setter
    def last_access_time(self, last_access_time):
        """
        Sets the last_access_time of this CacheBlock.

        :param last_access_time: The last_access_time of this CacheBlock.
        :type: str
        """

        self._last_access_time = last_access_time

    @property
    def length_in_bytes(self):
        """
        Gets the length_in_bytes of this CacheBlock.

        :return: The length_in_bytes of this CacheBlock.
        :rtype: int
        """
        return self._length_in_bytes

    @length_in_bytes.setter
    def length_in_bytes(self, length_in_bytes):
        """
        Sets the length_in_bytes of this CacheBlock.

        :param length_in_bytes: The length_in_bytes of this CacheBlock.
        :type: int
        """

        self._length_in_bytes = length_in_bytes

    @property
    def length_in_datums(self):
        """
        Gets the length_in_datums of this CacheBlock.

        :return: The length_in_datums of this CacheBlock.
        :rtype: int
        """
        return self._length_in_datums

    @length_in_datums.setter
    def length_in_datums(self, length_in_datums):
        """
        Sets the length_in_datums of this CacheBlock.

        :param length_in_datums: The length_in_datums of this CacheBlock.
        :type: int
        """

        self._length_in_datums = length_in_datums

    @property
    def record_id(self):
        """
        Gets the record_id of this CacheBlock.

        :return: The record_id of this CacheBlock.
        :rtype: int
        """
        return self._record_id

    @record_id.setter
    def record_id(self, record_id):
        """
        Sets the record_id of this CacheBlock.

        :param record_id: The record_id of this CacheBlock.
        :type: int
        """

        self._record_id = record_id

    @property
    def samples(self):
        """
        Gets the samples of this CacheBlock.

        :return: The samples of this CacheBlock.
        :rtype: list[SampleOutputV1]
        """
        return self._samples

    @samples.setter
    def samples(self, samples):
        """
        Sets the samples of this CacheBlock.

        :param samples: The samples of this CacheBlock.
        :type: list[SampleOutputV1]
        """

        self._samples = samples

    @property
    def series_id(self):
        """
        Gets the series_id of this CacheBlock.

        :return: The series_id of this CacheBlock.
        :rtype: str
        """
        return self._series_id

    @series_id.setter
    def series_id(self, series_id):
        """
        Sets the series_id of this CacheBlock.

        :param series_id: The series_id of this CacheBlock.
        :type: str
        """

        self._series_id = series_id

    @property
    def ttl(self):
        """
        Gets the ttl of this CacheBlock.

        :return: The ttl of this CacheBlock.
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """
        Sets the ttl of this CacheBlock.

        :param ttl: The ttl of this CacheBlock.
        :type: int
        """

        self._ttl = ttl

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CacheBlock):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ServerSpecOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _component_name: Optional[str]
    _error: Optional[bool]
    _message: Optional[str]
    _system_spec_value: Optional[str]
    _warning: Optional[bool]


    def __init__(
        self,
        component_name: Optional[str] = None,
        error: Optional[bool] = False,
        message: Optional[str] = None,
        system_spec_value: Optional[str] = None,
        warning: Optional[bool] = False,
    ) -> None: ...

    @property
    def component_name(self) -> Optional[str]: ...

    @component_name.setter
    def component_name(self, component_name: Optional[str]) -> None: ...

    @property
    def error(self) -> Optional[bool]: ...

    @error.setter
    def error(self, error: Optional[bool]) -> None: ...

    @property
    def message(self) -> Optional[str]: ...

    @message.setter
    def message(self, message: Optional[str]) -> None: ...

    @property
    def system_spec_value(self) -> Optional[str]: ...

    @system_spec_value.setter
    def system_spec_value(self, system_spec_value: Optional[str]) -> None: ...

    @property
    def warning(self) -> Optional[bool]: ...

    @warning.setter
    def warning(self, warning: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FoldedStackNodeV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _children: List[FoldedStackNodeV1]
    _interval_end: Optional[int]
    _interval_start: Optional[int]
    _name: str
    _properties: Dict[str, str]
    _value: int


    def __init__(
        self,
        children: Optional[List[FoldedStackNodeV1]] = None,
        interval_end: Optional[int] = None,
        interval_start: Optional[int] = None,
        name: Optional[str] = None,
        properties: Optional[Dict[str, str]] = None,
        value: Optional[int] = None,
    ) -> None: ...

    @property
    def children(self) -> List[FoldedStackNodeV1]: ...

    @children.setter
    def children(self, children: List[FoldedStackNodeV1]) -> None: ...

    @property
    def interval_end(self) -> Optional[int]: ...

    @interval_end.setter
    def interval_end(self, interval_end: Optional[int]) -> None: ...

    @property
    def interval_start(self) -> Optional[int]: ...

    @interval_start.setter
    def interval_start(self, interval_start: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def properties(self) -> Dict[str, str]: ...

    @properties.setter
    def properties(self, properties: Dict[str, str]) -> None: ...

    @property
    def value(self) -> int: ...

    @value.setter
    def value(self, value: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class HierarchiesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputV1: ...

    def create_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchies(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputListV1: ...

    def get_hierarchies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputV1: ...

    def get_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchy_node(
        self,
        **kwargs: Any,
    ) -> HierarchyNodeWithPathOutputV1: ...

    def get_hierarchy_node_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_hierarchy_nodes(
        self,
        **kwargs: Any,
    ) -> HierarchyNodeOutputListV1: ...

    def get_hierarchy_nodes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search_hierarchy_node(
        self,
        **kwargs: Any,
    ) -> HierarchyNodeWithPathOutputV1: ...

    def search_hierarchy_node_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyOutputV1: ...

    def update_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_hierarchy(
        self,
        **kwargs: Any,
    ) -> HierarchyValidationOutputV1: ...

    def validate_hierarchy_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_hierarchy_input(
        self,
        **kwargs: Any,
    ) -> HierarchyValidationOutputV1: ...

    def validate_hierarchy_input_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AddOnToolOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _icon_class: str
    _id: str
    _in_development: Optional[bool]
    _installer: Optional[IdentityPreviewV1]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _launch_location: str
    _link_type: str
    _name: str
    _reuse_window: bool
    _sort_key: str
    _status_message: Optional[str]
    _target_url: str
    _translation_key: Optional[str]
    _type: str
    _window_details: str


    def __init__(
        self,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        icon_class: Optional[str] = None,
        id: Optional[str] = None,
        in_development: Optional[bool] = None,
        installer: Optional[IdentityPreviewV1] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        launch_location: Optional[str] = None,
        link_type: Optional[str] = None,
        name: Optional[str] = None,
        reuse_window: Optional[bool] = False,
        sort_key: Optional[str] = None,
        status_message: Optional[str] = None,
        target_url: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        window_details: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def icon_class(self) -> str: ...

    @icon_class.setter
    def icon_class(self, icon_class: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def in_development(self) -> Optional[bool]: ...

    @in_development.setter
    def in_development(self, in_development: Optional[bool]) -> None: ...

    @property
    def installer(self) -> Optional[IdentityPreviewV1]: ...

    @installer.setter
    def installer(self, installer: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def launch_location(self) -> str: ...

    @launch_location.setter
    def launch_location(self, launch_location: str) -> None: ...

    @property
    def link_type(self) -> str: ...

    @link_type.setter
    def link_type(self, link_type: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def reuse_window(self) -> bool: ...

    @reuse_window.setter
    def reuse_window(self, reuse_window: bool) -> None: ...

    @property
    def sort_key(self) -> str: ...

    @sort_key.setter
    def sort_key(self, sort_key: str) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def target_url(self) -> str: ...

    @target_url.setter
    def target_url(self, target_url: str) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def window_details(self) -> str: ...

    @window_details.setter
    def window_details(self, window_details: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ScheduledNotebookInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _enabled: Optional[bool]
    _file_path: str
    _label: Optional[str]
    _notify_on_automatic_unschedule: Optional[bool]
    _notify_on_skipped_execution: Optional[bool]
    _schedules: Optional[List[ScheduleInputV1]]
    _timezone: Optional[str]
    _user_id: Optional[str]


    def __init__(
        self,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        file_path: Optional[str] = None,
        label: Optional[str] = None,
        notify_on_automatic_unschedule: Optional[bool] = True,
        notify_on_skipped_execution: Optional[bool] = True,
        schedules: Optional[List[ScheduleInputV1]] = None,
        timezone: Optional[str] = None,
        user_id: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def file_path(self) -> str: ...

    @file_path.setter
    def file_path(self, file_path: str) -> None: ...

    @property
    def label(self) -> Optional[str]: ...

    @label.setter
    def label(self, label: Optional[str]) -> None: ...

    @property
    def notify_on_automatic_unschedule(self) -> Optional[bool]: ...

    @notify_on_automatic_unschedule.setter
    def notify_on_automatic_unschedule(self, notify_on_automatic_unschedule: Optional[bool]) -> None: ...

    @property
    def notify_on_skipped_execution(self) -> Optional[bool]: ...

    @notify_on_skipped_execution.setter
    def notify_on_skipped_execution(self, notify_on_skipped_execution: Optional[bool]) -> None: ...

    @property
    def schedules(self) -> Optional[List[ScheduleInputV1]]: ...

    @schedules.setter
    def schedules(self, schedules: Optional[List[ScheduleInputV1]]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def user_id(self) -> Optional[str]: ...

    @user_id.setter
    def user_id(self, user_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContentInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _analysis_view_type: Optional[str]
    _archived: Optional[bool]
    _asset_selection_id: Optional[str]
    _date_range_id: Optional[str]
    _description: Optional[str]
    _fill_to_fit: Optional[bool]
    _height: int
    _hide_uncertainty: Optional[bool]
    _name: str
    _react: Optional[bool]
    _report_id: Optional[str]
    _scale: Optional[float]
    _selector: Optional[str]
    _summary_type: Optional[str]
    _summary_value: Optional[str]
    _timezone: Optional[str]
    _width: int
    _worksheet_id: str
    _workstep_id: str


    def __init__(
        self,
        analysis_view_type: Optional[str] = None,
        archived: Optional[bool] = False,
        asset_selection_id: Optional[str] = None,
        date_range_id: Optional[str] = None,
        description: Optional[str] = None,
        fill_to_fit: Optional[bool] = False,
        height: Optional[int] = None,
        hide_uncertainty: Optional[bool] = None,
        name: Optional[str] = None,
        react: Optional[bool] = False,
        report_id: Optional[str] = None,
        scale: Optional[float] = None,
        selector: Optional[str] = None,
        summary_type: Optional[str] = None,
        summary_value: Optional[str] = None,
        timezone: Optional[str] = None,
        width: Optional[int] = None,
        worksheet_id: Optional[str] = None,
        workstep_id: Optional[str] = None,
    ) -> None: ...

    @property
    def analysis_view_type(self) -> Optional[str]: ...

    @analysis_view_type.setter
    def analysis_view_type(self, analysis_view_type: Optional[str]) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def asset_selection_id(self) -> Optional[str]: ...

    @asset_selection_id.setter
    def asset_selection_id(self, asset_selection_id: Optional[str]) -> None: ...

    @property
    def date_range_id(self) -> Optional[str]: ...

    @date_range_id.setter
    def date_range_id(self, date_range_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def fill_to_fit(self) -> Optional[bool]: ...

    @fill_to_fit.setter
    def fill_to_fit(self, fill_to_fit: Optional[bool]) -> None: ...

    @property
    def height(self) -> int: ...

    @height.setter
    def height(self, height: int) -> None: ...

    @property
    def hide_uncertainty(self) -> Optional[bool]: ...

    @hide_uncertainty.setter
    def hide_uncertainty(self, hide_uncertainty: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def react(self) -> Optional[bool]: ...

    @react.setter
    def react(self, react: Optional[bool]) -> None: ...

    @property
    def report_id(self) -> Optional[str]: ...

    @report_id.setter
    def report_id(self, report_id: Optional[str]) -> None: ...

    @property
    def scale(self) -> Optional[float]: ...

    @scale.setter
    def scale(self, scale: Optional[float]) -> None: ...

    @property
    def selector(self) -> Optional[str]: ...

    @selector.setter
    def selector(self, selector: Optional[str]) -> None: ...

    @property
    def summary_type(self) -> Optional[str]: ...

    @summary_type.setter
    def summary_type(self, summary_type: Optional[str]) -> None: ...

    @property
    def summary_value(self) -> Optional[str]: ...

    @summary_value.setter
    def summary_value(self, summary_value: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def width(self) -> int: ...

    @width.setter
    def width(self, width: int) -> None: ...

    @property
    def worksheet_id(self) -> str: ...

    @worksheet_id.setter
    def worksheet_id(self, worksheet_id: str) -> None: ...

    @property
    def workstep_id(self) -> str: ...

    @workstep_id.setter
    def workstep_id(self, workstep_id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class UserGroupsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_identity_to_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def add_identity_to_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def archive_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def create_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def disable_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def disable_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_capability_user_groups(
        self,
        **kwargs: Any,
    ) -> IdentityPreviewListV1: ...

    def get_capability_user_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def get_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user_groups(
        self,
        **kwargs: Any,
    ) -> IdentityPreviewListV1: ...

    def get_user_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_user_groups(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def put_user_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_identity_from_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def remove_identity_from_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_user_group(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def remove_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_user_group(
        self,
        **kwargs: Any,
    ) -> UserGroupOutputV1: ...

    def update_user_group_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DisplayOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _data_id: str
    _datasource_class: str
    _datasource_id: str
    _description: Optional[str]
    _effective_permissions: PermissionsV1
    _id: str
    _is_archived: Optional[bool]
    _name: str
    _scoped_to: Optional[str]
    _status_message: str
    _swap: Optional[SwapOutputV1]
    _sync_token: str
    _template: DisplayTemplateOutputV1
    _type: str


    def __init__(
        self,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = None,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        swap: Optional[SwapOutputV1] = None,
        sync_token: Optional[str] = None,
        template: Optional[DisplayTemplateOutputV1] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def data_id(self) -> str: ...

    @data_id.setter
    def data_id(self, data_id: str) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> PermissionsV1: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: PermissionsV1) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> str: ...

    @status_message.setter
    def status_message(self, status_message: str) -> None: ...

    @property
    def swap(self) -> Optional[SwapOutputV1]: ...

    @swap.setter
    def swap(self, swap: Optional[SwapOutputV1]) -> None: ...

    @property
    def sync_token(self) -> str: ...

    @sync_token.setter
    def sync_token(self, sync_token: str) -> None: ...

    @property
    def template(self) -> DisplayTemplateOutputV1: ...

    @template.setter
    def template(self, template: DisplayTemplateOutputV1) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AddOnPreviewV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _add_on_identifier: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _id: Optional[str]
    _in_development: Optional[bool]
    _installer: Optional[IdentityPreviewV1]


    def __init__(
        self,
        add_on_identifier: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        in_development: Optional[bool] = None,
        installer: Optional[IdentityPreviewV1] = None,
    ) -> None: ...

    @property
    def add_on_identifier(self) -> Optional[str]: ...

    @add_on_identifier.setter
    def add_on_identifier(self, add_on_identifier: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def in_development(self) -> Optional[bool]: ...

    @in_development.setter
    def in_development(self, in_development: Optional[bool]) -> None: ...

    @property
    def installer(self) -> Optional[IdentityPreviewV1]: ...

    @installer.setter
    def installer(self, installer: Optional[IdentityPreviewV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConfigurationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _configuration_options: List[ConfigurationOptionOutputV1]
    _limit: Optional[int]
    _next: Optional[str]
    _offset: Optional[int]
    _prev: Optional[str]
    _status_message: Optional[str]
    _total_results: int


    def __init__(
        self,
        configuration_options: Optional[List[ConfigurationOptionOutputV1]] = None,
        limit: Optional[int] = None,
        next: Optional[str] = None,
        offset: Optional[int] = None,
        prev: Optional[str] = None,
        status_message: Optional[str] = None,
        total_results: Optional[int] = None,
    ) -> None: ...

    @property
    def configuration_options(self) -> List[ConfigurationOptionOutputV1]: ...

    @configuration_options.setter
    def configuration_options(self, configuration_options: List[ConfigurationOptionOutputV1]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def next(self) -> Optional[str]: ...

    @next.setter
    def next(self, next: Optional[str]) -> None: ...

    @property
    def offset(self) -> Optional[int]: ...

    @offset.setter
    def offset(self, offset: Optional[int]) -> None: ...

    @property
    def prev(self) -> Optional[str]: ...

    @prev.setter
    def prev(self, prev: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def total_results(self) -> int: ...

    @total_results.setter
    def total_results(self, total_results: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ExportItemsOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _autoupdate_time_range: Optional[bool]
    _capsule_time: Optional[bool]
    _chain_view: Optional[bool]
    _created_at: Optional[str]
    _creator: Optional[IdentityPreviewV1]
    _export_capsules: Optional[bool]
    _export_name: Optional[str]
    _exported_item_schema: Optional[str]
    _grid_enabled: Optional[bool]
    _grid_origin: Optional[str]
    _grid_size: Optional[str]
    _href: Optional[str]
    _href_legacy: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _items: List[ExportItemV1]
    _name: Optional[str]
    _original_timestamps_enabled: Optional[bool]
    _scoped_to: Optional[str]
    _status_message: Optional[str]
    _swap_in: Optional[str]
    _swap_out: Optional[str]
    _time_zone: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        autoupdate_time_range: Optional[bool] = False,
        capsule_time: Optional[bool] = False,
        chain_view: Optional[bool] = False,
        created_at: Optional[str] = None,
        creator: Optional[IdentityPreviewV1] = None,
        export_capsules: Optional[bool] = False,
        export_name: Optional[str] = None,
        exported_item_schema: Optional[str] = None,
        grid_enabled: Optional[bool] = False,
        grid_origin: Optional[str] = None,
        grid_size: Optional[str] = None,
        href: Optional[str] = None,
        href_legacy: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        items: Optional[List[ExportItemV1]] = None,
        name: Optional[str] = None,
        original_timestamps_enabled: Optional[bool] = False,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        swap_in: Optional[str] = None,
        swap_out: Optional[str] = None,
        time_zone: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def autoupdate_time_range(self) -> Optional[bool]: ...

    @autoupdate_time_range.setter
    def autoupdate_time_range(self, autoupdate_time_range: Optional[bool]) -> None: ...

    @property
    def capsule_time(self) -> Optional[bool]: ...

    @capsule_time.setter
    def capsule_time(self, capsule_time: Optional[bool]) -> None: ...

    @property
    def chain_view(self) -> Optional[bool]: ...

    @chain_view.setter
    def chain_view(self, chain_view: Optional[bool]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator(self) -> Optional[IdentityPreviewV1]: ...

    @creator.setter
    def creator(self, creator: Optional[IdentityPreviewV1]) -> None: ...

    @property
    def export_capsules(self) -> Optional[bool]: ...

    @export_capsules.setter
    def export_capsules(self, export_capsules: Optional[bool]) -> None: ...

    @property
    def export_name(self) -> Optional[str]: ...

    @export_name.setter
    def export_name(self, export_name: Optional[str]) -> None: ...

    @property
    def exported_item_schema(self) -> Optional[str]: ...

    @exported_item_schema.setter
    def exported_item_schema(self, exported_item_schema: Optional[str]) -> None: ...

    @property
    def grid_enabled(self) -> Optional[bool]: ...

    @grid_enabled.setter
    def grid_enabled(self, grid_enabled: Optional[bool]) -> None: ...

    @property
    def grid_origin(self) -> Optional[str]: ...

    @grid_origin.setter
    def grid_origin(self, grid_origin: Optional[str]) -> None: ...

    @property
    def grid_size(self) -> Optional[str]: ...

    @grid_size.setter
    def grid_size(self, grid_size: Optional[str]) -> None: ...

    @property
    def href(self) -> Optional[str]: ...

    @href.setter
    def href(self, href: Optional[str]) -> None: ...

    @property
    def href_legacy(self) -> Optional[str]: ...

    @href_legacy.setter
    def href_legacy(self, href_legacy: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def items(self) -> List[ExportItemV1]: ...

    @items.setter
    def items(self, items: List[ExportItemV1]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def original_timestamps_enabled(self) -> Optional[bool]: ...

    @original_timestamps_enabled.setter
    def original_timestamps_enabled(self, original_timestamps_enabled: Optional[bool]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def swap_in(self) -> Optional[str]: ...

    @swap_in.setter
    def swap_in(self, swap_in: Optional[str]) -> None: ...

    @property
    def swap_out(self) -> Optional[str]: ...

    @swap_out.setter
    def swap_out(self, swap_out: Optional[str]) -> None: ...

    @property
    def time_zone(self) -> Optional[str]: ...

    @time_zone.setter
    def time_zone(self, time_zone: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
